@@ -65,6 +65,30 @@ class TestLogger(nuclio_sdk.test.TestCase):
             self._io.getvalue(),
         )
 
+    def test_log_nan(self):
+        self._logger.info_with(self._testMethodName, nan=float("NaN"))
+        self.assertIn(self._testMethodName, self._io.getvalue())
+        self.assertIn(
+            '"with": {"nan": "NaN"}',
+            self._io.getvalue(),
+        )
+
+    def test_log_infinity(self):
+        self._logger.info_with(self._testMethodName, nan=float("Infinity"))
+        self.assertIn(self._testMethodName, self._io.getvalue())
+        self.assertIn(
+            '"with": {"nan": "Infinity"}',
+            self._io.getvalue(),
+        )
+
+    def test_log_minus_infinity(self):
+        self._logger.info_with(self._testMethodName, nan=float("-Infinity"))
+        self.assertIn(self._testMethodName, self._io.getvalue())
+        self.assertIn(
+            '"with": {"nan": "-Infinity"}',
+            self._io.getvalue(),
+        )
+
     def test_fail_to_log(self):
         """
         Do not fail logging when an object is not log-able
